**solve-sum-minmax** is used to solve a sum of min/max equations in python by 
using numerical methods. For instance, say you want to solve this equation: 
min(400, 500*x) + min(200, 500*x) + min(0, 500*x) = 700 
with the assumption that
x is within range (0, 1).  
In Math, the rigorous way would 
require you to set up all possible conditions, which 
might result in huge computation. 
Currently, there isn't any available packages in Python
that allows you to solve this kind of equation fastly with minimum codes. Thus,
this package is developed to fill the void and hopefully be of use to the 
broad population.
**current version**: 0.0.1  
**email**: yz4175@columbia.edu  
**disclaimer**:this package is still under development, the current version
only has very limited functionality
**collaboration**: collaborations are welcomed, please send me an email if you 
are interested.